<?php

namespace WeStacks\TeleBot\Objects;

use WeStacks\TeleBot\Contracts\TelegramObject;

/**
 * This object represents a general file (as opposed to [photos](https://core.telegram.org/bots/api#photosize), [voice messages](https://core.telegram.org/bots/api#voice) and [audio files](https://core.telegram.org/bots/api#audio)).
 *
 * @property string    $file_id        Identifier for this file, which can be used to download or reuse the file
 * @property string    $file_unique_id Unique identifier for this file, which is supposed to be the same over time and for different bots. Can't be used to download or reuse the file.
 * @property PhotoSize $thumb          Optional. Document thumbnail as defined by sender
 * @property string    $file_name      Optional. Original filename as defined by sender
 * @property string    $mime_type      Optional. MIME type of the file as defined by sender
 * @property int       $file_size      Optional. File size in bytes
 */
class Document extends TelegramObject
{
    protected $attributes = [
        'file_id'        => 'string',
        'file_unique_id' => 'string',
        'thumb'          => 'PhotoSize',
        'file_name'      => 'string',
        'mime_type'      => 'string',
        'file_size'      => 'integer',
    ];
}
